from setuptools import setup

setup(name='dice_prob_distribution',
      version='1.2',
      description='Gaussian and Binomial distributions calculations',
      packages=['dice_prob_distribution'],
      author='Desmond Odera',
      zip_safe=False)
